pub enum InsertionPosition {
Any,
Concrete(usize),
Last,
}Expand description
Specifies allowed insertion position in route for the job.
Variants
Any
Job can be inserted anywhere in the route.
Concrete(usize)
Job can be inserted only at the leg with the concrete index.
Last
Job can be inserted only to the end of the route.