pub enum MoveContext<'a> {
Route {
solution_ctx: &'a SolutionContext,
route_ctx: &'a RouteContext,
job: &'a Job,
},
Activity {
route_ctx: &'a RouteContext,
activity_ctx: &'a ActivityContext<'a>,
},
}Expand description
A local move context.
Variants
Route
Evaluation of job insertion into the given route.
Fields

solution_ctx: &'a SolutionContextA solution context.

route_ctx: &'a RouteContextA route context where job supposed to be inserted.
Activity
Evaluation of activity insertion into the given position.
Fields

route_ctx: &'a RouteContextA route context where activity supposed to be inserted.

activity_ctx: &'a ActivityContext<'a>An activity context.
Implementations
Sourceimpl<'a> MoveContext<'a>
impl<'a> MoveContext<'a>
Sourcepub fn route(
solution_ctx: &'a SolutionContext,
route_ctx: &'a RouteContext,
job: &'a Job,
) -> MoveContext<'a>
pub fn route( solution_ctx: &'a SolutionContext, route_ctx: &'a RouteContext, job: &'a Job, ) -> MoveContext<'a>
Creates a route variant for MoveContext.
Sourcepub fn activity(
route_ctx: &'a RouteContext,
activity_ctx: &'a ActivityContext<'_>,
) -> MoveContext<'a>
pub fn activity( route_ctx: &'a RouteContext, activity_ctx: &'a ActivityContext<'_>, ) -> MoveContext<'a>
Creates a route variant for MoveContext.