RouteState

Struct RouteState 

pub struct RouteState { /* private fields */ }
Provides a way to associate arbitrary data within route or/and activity. NOTE: do not put any state that is not refreshed after accept_route_state call: it will be wiped out at some point.

Implementations

Source

impl RouteState

pub fn get_tour_state<K: 'static, V: Send + Sync + 'static>(&self) -> Option<&V>

Gets a value associated with the tour using K type as a key.

pub fn set_tour_state<K: 'static, V: Send + Sync + 'static>(&mut self, value: V)

Sets the value associated with the tour using K type as a key.

pub fn remove_tour_state<K: 'static>(&mut self) -> bool

Removes the value associated with the tour using K type as a key. Returns true if the value was present.

pub fn get_activity_state<K: 'static, V: Send + Sync + 'static>( &self, activity_idx: usize, ) -> Option<&V>

Gets value associated with a key converted to a given type.

pub fn get_activity_states<K: 'static, V: Send + Sync + 'static>( &self, ) -> Option<&Vec<V>>

Gets values associated with key and activities.

pub fn set_activity_states<K: 'static, V: Send + Sync + 'static>( &mut self, values: Vec<V>, )

Adds values associated with activities.

pub fn clear(&mut self)

Clear all states.