pub struct Multi {
pub jobs: Vec<Arc<Single>>,
pub dimens: Dimensions,
/* private fields */
}Expand description
Represents a job which consists of multiple sub jobs. All of these jobs must be performed or none of them. Order can be controlled via specific dimension value.
Fields
jobs: Vec<Arc<Single>>A list of jobs which must be performed.
dimens: DimensionsDimensions which contains extra work requirements.
Implementations