ConstraintViolation

Struct ConstraintViolation 

pub struct ConstraintViolation {
    pub code: ViolationCode,
    pub stopped: bool,
}
Specifies a result of hard route constraint check.

Fields

code: ViolationCode

Violation code which is used as marker of specific constraint violated.

stopped: bool

True if further insertions should not be attempted.

Implementations

Source

impl ConstraintViolation

pub fn fail(code: ViolationCode) -> Option<Self>

A constraint violation failure with stopped set to true.

Examples found in repository?
examples/custom_constraint.rs (line 41)
31    fn evaluate(&self, move_ctx: &MoveContext<'_>) -> Option<ConstraintViolation> {
32        match move_ctx {
33            // matching job to route is evaluated before activity matching, so use it to improve search procedure
34            MoveContext::Route { route_ctx, job, .. } => {
35                let hardware_vehicle = route_ctx.route().actor.vehicle.dimens.get_vehicle_hardware();
36                let hardware_job = job.dimens().get_job_hardware();
37
38                match (hardware_job, hardware_vehicle) {
39                    (None, _) => None,
40                    (Some(hw_job), Some(hw_vehicle)) if hw_vehicle.contains(hw_job) => None,
41                    _ => ConstraintViolation::fail(self.code),
42                }
43            }
44            // matching activity to route is called for every possible insertion point in the tour
45            // we don't need it here as hard constraint can be validated on route-job level
46            MoveContext::Activity { .. } => None,
47        }
48    }
pub fn skip(code: ViolationCode) -> Option<Self>

A constraint violation failure with stopped set to false.

pub fn success() -> Option<Self>

No constraint violation.