pub struct WorstJobRemoval { /* private fields */ }Expand description
A ruin strategy which detects the most cost expensive jobs in each route and delete them with their neighbours.
Implementations
Sourceimpl WorstJobRemoval
impl WorstJobRemoval
Sourcepub fn new(worst_skip: usize, limits: RemovalLimits) -> Self
pub fn new(worst_skip: usize, limits: RemovalLimits) -> Self
Creates a new instance of WorstJobRemoval.