pub struct RouteState { /* private fields */ }Expand description
Provides a way to associate arbitrary data within route or/and activity.
NOTE: do not put any state that is not refreshed after accept_route_state call: it will be
wiped out at some point.
Implementations
Sourceimpl RouteState
impl RouteState
Sourcepub fn get_tour_state<K: 'static, V: Send + Sync + 'static>(&self) -> Option<&V>
pub fn get_tour_state<K: 'static, V: Send + Sync + 'static>(&self) -> Option<&V>
Gets a value associated with the tour using K type as a key.
Sourcepub fn set_tour_state<K: 'static, V: Send + Sync + 'static>(&mut self, value: V)
pub fn set_tour_state<K: 'static, V: Send + Sync + 'static>(&mut self, value: V)
Sets the value associated with the tour using K type as a key.
Sourcepub fn remove_tour_state<K: 'static>(&mut self) -> bool
pub fn remove_tour_state<K: 'static>(&mut self) -> bool
Removes the value associated with the tour using K type as a key. Returns true if the
value was present.
Sourcepub fn get_activity_state<K: 'static, V: Send + Sync + 'static>(
&self,
activity_idx: usize,
) -> Option<&V>
pub fn get_activity_state<K: 'static, V: Send + Sync + 'static>( &self, activity_idx: usize, ) -> Option<&V>
Gets value associated with a key converted to a given type.
Sourcepub fn get_activity_states<K: 'static, V: Send + Sync + 'static>(
&self,
) -> Option<&Vec<V>>
pub fn get_activity_states<K: 'static, V: Send + Sync + 'static>( &self, ) -> Option<&Vec<V>>
Gets values associated with key and activities.
Sourcepub fn set_activity_states<K: 'static, V: Send + Sync + 'static>(
&mut self,
values: Vec<V>,
)
pub fn set_activity_states<K: 'static, V: Send + Sync + 'static>( &mut self, values: Vec<V>, )
Adds values associated with activities.